# mypy-baseline

```{include} ../README.md
:start-after: "# mypy-baseline"
:end-before: "## Usage"
```

Source code is available on GitHub: [github.com/orsinium-labs/mypy-baseline](https://github.com/orsinium-labs/mypy-baseline)

## Documentation

```{eval-rst}

.. toctree::
    :maxdepth: 1
    :caption: Guides

    usage
    config
    leader
    follower

.. toctree::
    :maxdepth: 1
    :caption: Commands

    sync
    filter
    suggest
    history
    plot
    top-files
```
